'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var splitSdkProvider = require('@personio-internal/split-sdk-provider');

var React = require('react');

function _interopDefaultLegacy(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    'default': e
  };
}

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

var DYNAMIC_COMPONENT_MARK = 'function () { return Promise.resolve().then(';
exports.FeatureFlag = void 0;

(function (FeatureFlag) {
  FeatureFlag["EnableNewTokens"] = "DST-enable-new-tokens";
  FeatureFlag["EnableNewDesign"] = "DST-enable-new-design";
})(exports.FeatureFlag || (exports.FeatureFlag = {}));

var HUI_CLASS_PREFIX = 'hui-tokens';
exports.VisualLanguage = void 0;

(function (VisualLanguage) {
  VisualLanguage["default"] = "default";
})(exports.VisualLanguage || (exports.VisualLanguage = {}));

var HighlightContext = React__default["default"].createContext(undefined);

var applyStyles = function (ready) {
  var html = document.documentElement;
  if (html.dataset.hasSplit) return;
  html.style.pointerEvents = ready ? '' : 'none';
  html.style.userSelect = ready ? '' : 'none';
  html.style.visibility = ready ? '' : 'hidden';
  if (ready) html.dataset.hasSplit = 'true';
};

function HighlightProvider(_a) {
  var children = _a.children;
  var newDesignFlag = splitSdkProvider.useFeatureFlag(exports.FeatureFlag.EnableNewDesign);
  var newTokensFlag = splitSdkProvider.useFeatureFlag(exports.FeatureFlag.EnableNewTokens);
  var ready = newTokensFlag.isReady && newDesignFlag.isReady;
  var value = React.useMemo(function () {
    return {
      newDesignEnabled: newDesignFlag.isOn,
      newTokensEnabled: newTokensFlag.isOn
    };
  }, [newDesignFlag.isOn, newTokensFlag.isOn]);
  React.useEffect(function () {
    applyStyles(ready);
  }, [ready]);
  return React__default["default"].createElement(HighlightContext.Provider, {
    value: value
  }, children);
}

function useHighlightContext() {
  var context = React.useContext(HighlightContext);

  if (context === undefined) {
    throw new Error('useHighlightContext must be used within a HighlightProvider');
  }

  return context;
}

function useVisualLanguage(_a) {
  var _b = _a === void 0 ? {} : _a,
      _c = _b.flag,
      flag = _c === void 0 ? exports.FeatureFlag.EnableNewTokens : _c,
      forceVisualLanguage = _b.forceVisualLanguage,
      _d = _b.visualLanguage,
      visualLanguage = _d === void 0 ? exports.VisualLanguage.default : _d;

  var _e = useHighlightContext(),
      newTokensEnabled = _e.newTokensEnabled,
      newDesignEnabled = _e.newDesignEnabled;

  var isOn = splitSdkProvider.useFeatureFlag(flag).isOn;
  var enabled = isOn || newTokensEnabled || forceVisualLanguage;
  var appliedVisualLanguage = forceVisualLanguage || visualLanguage;
  var className = enabled ? HUI_CLASS_PREFIX + "-" + appliedVisualLanguage : undefined;
  return {
    newDesignEnabled: newDesignEnabled,
    newTokensEnabled: newTokensEnabled,
    visualLanguageClassName: className
  };
}
/* eslint-disable import/prefer-default-export */


var isDynamicComponent = function (component) {
  var str = String(component);
  return str.startsWith(DYNAMIC_COMPONENT_MARK);
};

var DesignSwitch = function (_a) {
  var fallback = _a.fallback,
      _b = _a.flag,
      flag = _b === void 0 ? exports.FeatureFlag.EnableNewDesign : _b,
      on = _a.on,
      off = _a.off;
  var newDesignEnabled = useVisualLanguage().newDesignEnabled;

  var _c = splitSdkProvider.useFeatureFlag(flag),
      isOn = _c.isOn,
      isReady = _c.isReady;

  if (!isReady) return React__default["default"].createElement(React__default["default"].Fragment, null, fallback);
  var enabled = isOn && isReady || newDesignEnabled;
  var winner = enabled ? on : off;
  if (!isDynamicComponent(winner)) return React__default["default"].createElement(React__default["default"].Fragment, null, winner);
  var LazyComponent = React__default["default"].lazy(winner);
  return React__default["default"].createElement(React.Suspense, {
    fallback: fallback
  }, React__default["default"].createElement(LazyComponent, null));
};

exports.DYNAMIC_COMPONENT_MARK = DYNAMIC_COMPONENT_MARK;
exports.DesignSwitch = DesignSwitch;
exports.HUI_CLASS_PREFIX = HUI_CLASS_PREFIX;
exports.HighlightProvider = HighlightProvider;
exports.useHighlightContext = useHighlightContext;
exports.useVisualLanguage = useVisualLanguage;
//# sourceMappingURL=index.js.map
