import { useFeatureFlag } from '@personio-internal/split-sdk-provider';
import React, { useMemo, useEffect, useContext, Suspense } from 'react';
var DYNAMIC_COMPONENT_MARK = 'function () { return Promise.resolve().then(';
var FeatureFlag;

(function (FeatureFlag) {
  FeatureFlag["EnableNewTokens"] = "DST-enable-new-tokens";
  FeatureFlag["EnableNewDesign"] = "DST-enable-new-design";
})(FeatureFlag || (FeatureFlag = {}));

var HUI_CLASS_PREFIX = 'hui-tokens';
var VisualLanguage;

(function (VisualLanguage) {
  VisualLanguage["default"] = "default";
})(VisualLanguage || (VisualLanguage = {}));

var HighlightContext = /*#__PURE__*/React.createContext(undefined);

var applyStyles = function (ready) {
  var html = document.documentElement;
  if (html.dataset.hasSplit) return;
  html.style.pointerEvents = ready ? '' : 'none';
  html.style.userSelect = ready ? '' : 'none';
  html.style.visibility = ready ? '' : 'hidden';
  if (ready) html.dataset.hasSplit = 'true';
};

function HighlightProvider(_a) {
  var children = _a.children;
  var newDesignFlag = useFeatureFlag(FeatureFlag.EnableNewDesign);
  var newTokensFlag = useFeatureFlag(FeatureFlag.EnableNewTokens);
  var ready = newTokensFlag.isReady && newDesignFlag.isReady;
  var value = useMemo(function () {
    return {
      newDesignEnabled: newDesignFlag.isOn,
      newTokensEnabled: newTokensFlag.isOn
    };
  }, [newDesignFlag.isOn, newTokensFlag.isOn]);
  useEffect(function () {
    applyStyles(ready);
  }, [ready]);
  return /*#__PURE__*/React.createElement(HighlightContext.Provider, {
    value: value
  }, children);
}

function useHighlightContext() {
  var context = useContext(HighlightContext);

  if (context === undefined) {
    throw new Error('useHighlightContext must be used within a HighlightProvider');
  }

  return context;
}

function useVisualLanguage(_a) {
  var _b = _a === void 0 ? {} : _a,
      _c = _b.flag,
      flag = _c === void 0 ? FeatureFlag.EnableNewTokens : _c,
      forceVisualLanguage = _b.forceVisualLanguage,
      _d = _b.visualLanguage,
      visualLanguage = _d === void 0 ? VisualLanguage.default : _d;

  var _e = useHighlightContext(),
      newTokensEnabled = _e.newTokensEnabled,
      newDesignEnabled = _e.newDesignEnabled;

  var isOn = useFeatureFlag(flag).isOn;
  var enabled = isOn || newTokensEnabled || forceVisualLanguage;
  var appliedVisualLanguage = forceVisualLanguage || visualLanguage;
  var className = enabled ? HUI_CLASS_PREFIX + "-" + appliedVisualLanguage : undefined;
  return {
    newDesignEnabled: newDesignEnabled,
    newTokensEnabled: newTokensEnabled,
    visualLanguageClassName: className
  };
}
/* eslint-disable import/prefer-default-export */


var isDynamicComponent = function (component) {
  var str = String(component);
  return str.startsWith(DYNAMIC_COMPONENT_MARK);
};

var DesignSwitch = function (_a) {
  var fallback = _a.fallback,
      _b = _a.flag,
      flag = _b === void 0 ? FeatureFlag.EnableNewDesign : _b,
      on = _a.on,
      off = _a.off;
  var newDesignEnabled = useVisualLanguage().newDesignEnabled;

  var _c = useFeatureFlag(flag),
      isOn = _c.isOn,
      isReady = _c.isReady;

  if (!isReady) return /*#__PURE__*/React.createElement(React.Fragment, null, fallback);
  var enabled = isOn && isReady || newDesignEnabled;
  var winner = enabled ? on : off;
  if (!isDynamicComponent(winner)) return /*#__PURE__*/React.createElement(React.Fragment, null, winner);
  var LazyComponent = /*#__PURE__*/React.lazy(winner);
  return /*#__PURE__*/React.createElement(Suspense, {
    fallback: fallback
  }, /*#__PURE__*/React.createElement(LazyComponent, null));
};

export { DYNAMIC_COMPONENT_MARK, DesignSwitch, FeatureFlag, HUI_CLASS_PREFIX, HighlightProvider, VisualLanguage, useHighlightContext, useVisualLanguage };
//# sourceMappingURL=index.js.map
